# Fungua Universe

![Funbanner](https://raw.githubusercontent.com/kivo360/funguauniverse/master/bann.png)

Universal Tools to run the Funguana Pipeline. The point to them is to go from backtest to live quickly. 





---

- [x] Add basic code
- [ ] Write documents on the use cases
